@@ -4,6 +4,7 @@
 const ExtensionUtils = imports.misc.extensionUtils;
 const Me = ExtensionUtils.getCurrentExtension();
 const { AppGridHelper, ExtensionHelper } = Me.imports.lib;
+const ShellVersion = ExtensionHelper.shellVersion;
 
 //Main imports
 const { GLib, Gio, Shell } = imports.gi;
@@ -12,7 +13,7 @@ const Main = imports.ui.main;
 //Access required objects and systems
 const AppDisplay = AppGridHelper.AppDisplay;
 const Controls = Main.overview._overview._controls;
-const Dash = Controls.dash;
+const OverviewControls = imports.ui.overviewControls;
 
 function init() {
   ExtensionUtils.initTranslations();
@@ -53,7 +54,7 @@ class Extension {
   }
 
   patchShell() {
-    //Patched functions delcared here for access to extension's variables
+    //Patched functions declared here for access to extension's variables
 
     //Patched version of _redisplay() to apply custom order
     function _patchedRedisplay() {
@@ -123,7 +124,7 @@ class Extension {
     this._waitForFolderChange();
 
     //One time connections
-    this._reorderOnceOnDisplay();
+    this._reorderOnDisplay();
 
     ExtensionHelper.logMessage('Connected to listeners');
   }
@@ -136,8 +137,8 @@ class Extension {
     Shell.AppSystem.get_default().disconnect(this._installedAppsChangedSignal);
     this.folderSettings.disconnect(this._foldersChangedSignal);
 
-    if (this._reorderOnceOnDisplaySignal != null) {
-      Dash.showAppsButton.disconnect(this._reorderOnceOnDisplaySignal);
+    if (this._reorderOnDisplaySignal != null) {
+      Controls._stateAdjustment.disconnect(this._reorderOnDisplaySignal);
     }
 
     //Clean up timeout sources
@@ -160,14 +161,17 @@ class Extension {
     });
   }
 
-  _reorderOnceOnDisplay() {
-    //Reorder once when the app grid is opened
-    this._reorderOnceOnDisplaySignal = Dash.showAppsButton.connect('notify::checked', () => {
-      //Only run required code if app overview toggle is usable
-      if (!Controls._ignoreShowAppsButtonToggle) {
-        this.reorderGrid('App grid opened, triggering one-off reorder');
-        Dash.showAppsButton.disconnect(this._reorderOnceOnDisplaySignal);
-        this._reorderOnceOnDisplaySignal = null;
+  _reorderOnDisplay() {
+    //Ignore this signal on GNOME 3.38
+    if (ShellVersion < 40) {
+      this._reorderOnDisplaySignal = null;
+      return;
+    }
+
+    //Reorder when the app grid is opened
+    this._reorderOnDisplaySignal = Controls._stateAdjustment.connect('notify::value', () => {
+      if (Controls._stateAdjustment.value == OverviewControls.ControlsState.APP_GRID) {
+        this.reorderGrid('App grid opened, triggering reorder');
       }
     });
   }
